This is package is under testing.
You might experience a lot of bugs; but  be rest assured that we are working on them.

A stable version will be released soon, with all infos
Contact miraclem2014@gmail.com for any info and enquiries

This package contains

Matrix: Giving python the ability to work directly on Matrices explicitly
Expressions: Algebraic Manipulations in form of Polynomials for python
Equations: Solving expressions, including Simultaneous equations
Fundamentals: Comprising basic math functions